Credits
-------

.. rst-class:: credits-list

- Michael Droettboom (founder)
- Pauli Virtanen
- Philippe Pepiot
- Thomas Robitaille
- Antoine Pitrou
- Matthew Turk
- Richard Hattersley
- Christopher Whelan
- Erik Tollerud
- Elliott Sales de Andrade
- @afragner
- Raphaël Gomès
- Andrew Nelson
- Juan Nunez-Iglesias
- Pierre Glaser
- Chris Beaumont
- Christoph Deil
- @Rok
- Robert T. McGibbon
- Andreas Fragner
- Jeremie du Boisberranger
- @wrwrwr
- Aaron Meurer
- Boris Feld
- Erik M. Bray
- Isuru Fernando
- Kacper Kowalik
- Tyler Reddy
- Yaroslav Halchenko
- Antony Lee
- Arne Neumann
- Colin Carroll
- Dieter Werthmüller
- Edison Gustavo Muenz
- Eric Dill
- Hans Moritz Günther
- John Kirkham
- Josh Soref
- Markus Mohrhard
- Mike Sarahan
- @MinRK
- Nathan Goldbaum
- P\. L. Lim
- Thomas Pfaff
- Tom Augspurger
- @Warbo
- Wojtek Ruszczewski
- @jbrockmendel
- @serge-sans-paille
